Residue: SQLAlchemy CRUD Utilities
==================================


Downloads and Docs
------------------

Full documentation is available on `Read the Docs
<http://residue.readthedocs.org>`_.

Built packages are available on `PyPI <https://pypi.python.org/pypi/residue>`_.

`Source code <https://github.com/RobRuana/residue>`_ is available on `GitHub
<https://github.com/RobRuana/residue>`_. Feel free to:

- `Create an issue <https://github.com/RobRuana/residue/issues>`_ to request a
  feature or a report a bug.
- `Fork the repository <https://github.com/RobRuana/residue/fork>`_ and make
  changes to the **master** branch for next release.
- Send a pull request and pester the maintainer until it's merged. Make sure
  to add yourself to `AUTHORS
  <https://github.com/RobRuana/residue/blob/master/AUTHORS>`_ and update
  `CHANGES <https://github.com/RobRuana/residue/blob/master/CHANGES>`_.


Build Status
------------

.. image:: https://travis-ci.org/RobRuana/residue.svg
    :target: https://travis-ci.org/RobRuana/residue
    :alt: Build Status


.. image:: https://coveralls.io/repos/RobRuana/residue/badge.svg
    :target: https://coveralls.io/r/RobRuana/residue
    :alt: Coverage Status


.. image:: https://readthedocs.org/projects/residue/badge/?version=latest
    :target: https://readthedocs.org/projects/residue/?badge=latest
    :alt: Documentation Status
